@@ -1,8 +1,8 @@
 name = "ttp"
 
-__all__ = ['ttp']
-__author__ = 'Denis Mulyalin <d.mulyalin@gmail.com>'
-__version__ = '0.0.2'
+__all__ = ["ttp"]
+__author__ = "Denis Mulyalin <d.mulyalin@gmail.com>"
+__version__ = "0.0.2"
 from sys import version_info
 
 # get python version:
@@ -11,4 +11,4 @@ python_major_version = version_info.major
 if python_major_version == 3:
     from ttp.ttp import ttp
 elif python_major_version == 2:
-    from ttp import ttp
\ No newline at end of file
+    from ttp import ttp
