@@ -1,9 +1,8 @@
-_name_map_ = {
-"delete_func": "del"
-}
+_name_map_ = {"delete_func": "del"}
+
 
 def delete_func(data, *args):
     for key in args:
         if key in data:
             _ = data.pop(key)
-    return data, None
\ No newline at end of file
+    return data, None
